--- a/Makefile	2020-06-05 20:28:12.691759233 +0200
+++ b/Makefile	2020-06-05 21:23:46.334235268 +0200
@@ -9,8 +9,12 @@
 STRIP        = $(CROSS_PREFIX)strip
 SHLIB        = $(CC) -shared
 STRIPLIB     = $(STRIP) --strip-unneeded
+LDCONFIG     = ldconfig
+PYTHON2      = $(shell type -P python2 || echo ':' 2> /dev/null)
+PYTHON3      = $(shell type -P python3 || echo ':' 2> /dev/null)
 
 SOVERSION    = 1
+LIBVERSION   = 1.0
 
 CFLAGS	+= -O3 -Wall -pthread
 
@@ -25,7 +29,7 @@
 
 LIB      = $(LIB1) $(LIB2) $(LIB3)
 
-ALL     = $(LIB) x_pigpio x_pigpiod_if x_pigpiod_if2 pig2vcd pigpiod pigs
+ALL     = $(LIB) pig2vcd pigpiod pigs
 
 LL1      = -L. -lpigpio -pthread -lrt
 
@@ -66,52 +70,43 @@
 	$(CC) -o x_pigpiod_if2 x_pigpiod_if2.o $(LL3)
 
 pigpiod:	pigpiod.o $(LIB1)
-	$(CC) -o pigpiod pigpiod.o $(LL1)
-	$(STRIP) pigpiod
+	$(CC) $(CFLAGS) $(LDFLAGS) -o pigpiod pigpiod.o $(LL1)
 
 pigs:		pigs.o command.o
-	$(CC) -o pigs pigs.o command.o
-	$(STRIP) pigs
+	$(CC) $(CFLAGS) $(LDFLAGS) -o pigs pigs.o command.o
 
 pig2vcd:	pig2vcd.o
-	$(CC) -o pig2vcd pig2vcd.o
-	$(STRIP) pig2vcd
+	$(CC) $(CFLAGS) $(LDFLAGS) -o pig2vcd pig2vcd.o
 
 clean:
 	rm -f *.o *.i *.s *~ $(ALL) *.so.$(SOVERSION)
 
-ifeq ($(DESTDIR),)
-  PYINSTALLARGS =
-else
-  PYINSTALLARGS = --root=$(DESTDIR)
-endif
-
 install:	$(ALL)
-	install -m 0755 -d                             $(DESTDIR)/opt/pigpio/cgi
 	install -m 0755 -d                             $(DESTDIR)$(includedir)
 	install -m 0644 pigpio.h                       $(DESTDIR)$(includedir)
 	install -m 0644 pigpiod_if.h                   $(DESTDIR)$(includedir)
 	install -m 0644 pigpiod_if2.h                  $(DESTDIR)$(includedir)
 	install -m 0755 -d                             $(DESTDIR)$(libdir)
-	install -m 0755 libpigpio.so.$(SOVERSION)      $(DESTDIR)$(libdir)
-	install -m 0755 libpigpiod_if.so.$(SOVERSION)  $(DESTDIR)$(libdir)
-	install -m 0755 libpigpiod_if2.so.$(SOVERSION) $(DESTDIR)$(libdir)
-	cd $(DESTDIR)$(libdir) && ln -fs libpigpio.so.$(SOVERSION)      libpigpio.so
-	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if.so.$(SOVERSION)  libpigpiod_if.so
-	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if2.so.$(SOVERSION) libpigpiod_if2.so
+	install -m 0755 libpigpio.so.$(LIBVERSION)      $(DESTDIR)$(libdir)
+	install -m 0755 libpigpiod_if.so.$(LIBVERSION)  $(DESTDIR)$(libdir)
+	install -m 0755 libpigpiod_if2.so.$(LIBVERSION) $(DESTDIR)$(libdir)
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpio.so.$(LIBVERSION)      libpigpio.so
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if.so.$(LIBVERSION)  libpigpiod_if.so
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if2.so.$(LIBVERSION) libpigpiod_if2.so
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpio.so.$(LIBVERSION)      libpigpio.so.$(SOVERSION)
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if.so.$(LIBVERSION)  libpigpiod_if.so.$(SOVERSION)
+	cd $(DESTDIR)$(libdir) && ln -fs libpigpiod_if2.so.$(LIBVERSION) libpigpiod_if2.so.$(SOVERSION)
 	install -m 0755 -d                             $(DESTDIR)$(bindir)
 	install -m 0755 pig2vcd                        $(DESTDIR)$(bindir)
 	install -m 0755 pigpiod                        $(DESTDIR)$(bindir)
 	install -m 0755 pigs                           $(DESTDIR)$(bindir)
-	if which python2; then python2 setup.py install $(PYINSTALLARGS); fi
-	if which python3; then python3 setup.py install $(PYINSTALLARGS); fi
+	$(PYTHON2) setup.py install
+	$(PYTHON3) setup.py install
 	install -m 0755 -d                             $(DESTDIR)$(mandir)/man1
-	install -m 0644 p*.1                           $(DESTDIR)$(mandir)/man1
+	install -m 0644 *.1                            $(DESTDIR)$(mandir)/man1
 	install -m 0755 -d                             $(DESTDIR)$(mandir)/man3
-	install -m 0644 p*.3                           $(DESTDIR)$(mandir)/man3
-ifeq ($(DESTDIR),)
-	ldconfig
-endif
+	install -m 0644 *.3                            $(DESTDIR)$(mandir)/man3
+	$(LDCONFIG)
 
 uninstall:
 	rm -f $(DESTDIR)$(includedir)/pigpio.h
@@ -136,22 +131,13 @@
 endif
 
 $(LIB1):	$(OBJ1)
-	$(SHLIB) -pthread -Wl,-soname,$(LIB1).$(SOVERSION) -o $(LIB1).$(SOVERSION) $(OBJ1)
-	ln -fs $(LIB1).$(SOVERSION) $(LIB1)
-	$(STRIPLIB) $(LIB1)
-	$(SIZE)     $(LIB1)
+	$(SHLIB) $(LDFLAGS) -Wl,-soname,$(LIB1).$(SOVERSION) -o $(LIB1).$(LIBVERSION) $(OBJ1)
 
 $(LIB2):	$(OBJ2)
-	$(SHLIB) -pthread -Wl,-soname,$(LIB2).$(SOVERSION) -o $(LIB2).$(SOVERSION) $(OBJ2)
-	ln -fs $(LIB2).$(SOVERSION) $(LIB2)
-	$(STRIPLIB) $(LIB2)
-	$(SIZE)     $(LIB2)
+	$(SHLIB) $(LDFLAGS) -Wl,-soname,$(LIB2).$(SOVERSION) -o $(LIB2).$(LIBVERSION) $(OBJ2)
 
 $(LIB3):	$(OBJ3)
-	$(SHLIB) -pthread -Wl,-soname,$(LIB3).$(SOVERSION) -o $(LIB3).$(SOVERSION) $(OBJ3)
-	ln -fs $(LIB3).$(SOVERSION) $(LIB3)
-	$(STRIPLIB) $(LIB3)
-	$(SIZE)     $(LIB3)
+	$(SHLIB) $(LDFLAGS) -Wl,-soname,$(LIB2).$(SOVERSION) -o $(LIB3).$(LIBVERSION) $(OBJ3)
 
 # generated using gcc -MM *.c
 
